resttools.replace_leaves_in_expr_with_rests
===========================================

.. autofunction:: abjad.tools.resttools.replace_leaves_in_expr_with_rests.replace_leaves_in_expr_with_rests
   :noindex:
